@@ -591,6 +591,10 @@ set_combo_items (GnomeEntry *gentry)
 
 		g_list_free (strings);
 	}
+	else
+	{
+		gtk_list_clear_items (GTK_LIST (GTK_COMBO (gentry)->list), 0, -1);
+	}
 
 	/* Restore the text in the entry and clear our changed flag. */
 
@@ -788,7 +792,7 @@ gnome_entry_save_history (GnomeEntry *gentry)
 	g_return_if_fail (gentry != NULL);
 	g_return_if_fail (GNOME_IS_ENTRY (gentry));
 
-	if (gnome_program_get_app_id (gnome_program_get()) == NULL ||
+	if (gnome_program_get_app_id (gnome_program_get ()) == NULL ||
 	    gentry->_priv->history_id == NULL)
 		return;
 
@@ -807,6 +811,8 @@ gnome_entry_save_history (GnomeEntry *gentry)
 		}
 	}
 
+	gconf_items = g_slist_reverse (gconf_items);
+
 	/* Save the list */
 	gentry->_priv->saving_history = TRUE;
 	gconf_client_set_list (gentry->_priv->gconf_client, key, GCONF_VALUE_STRING, gconf_items, NULL);
